# Simulate the casioplot module of the Python add-in for the Casio fx-9750III
# Copyright (C) 2022  Jeffry Johnston
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.

import tkinter

class _CasioPlotWindow:
	FG_COLOR = "#000000"
	BG_COLOR = "#d0d0d0"

	BW_ZOOM = 8
	BW_WIDTH = 128
	BW_HEIGHT = 64
	BW_TITLE = "Casio fx-9750GIII"

	pixels: dict[tuple[int, int], int] = {}
	root: tkinter.Tk

	def clear_screen(self):
		for o in self.pixels.values():
			self.canvas.delete(o)
		self.pixels.clear()

	def draw_rect(self, x: int, y: int, fill_color: str="#000000"):
		self.pixels[(x, y)] = self.canvas.create_rectangle(
			x * self.BW_ZOOM,
			y * self.BW_ZOOM,
			(x + 1) * self.BW_ZOOM,
			(y + 1) * self.BW_ZOOM,
			fill=fill_color, outline=""
		)

	def set_pixel(self, x: int, y: int, color: tuple[int, int, int]):
		key = (x, y)
		try:
			self.canvas.delete(self.pixels[key]) # type: ignore
			del self.pixels[key]
		except:
			pass
		if color[0] >= 248 and color[1] >= 252 and color[2] >= 248:
			return
		self.draw_rect(x, y, self.FG_COLOR)

	def get_pixel(self, x: int, y: int) -> tuple[int, int, int]:
		fill_color: str = \
			self.canvas.itemcget(self.pixels[(x, y)], "fill") # type: ignore
		return (
			int(fill_color[1: 3], 16),
			int(fill_color[3: 5], 16),
			int(fill_color[5: 7], 16)
		)

	def __init__(self):
		self.root = tkinter.Tk()
		self.root.protocol("WM_DELETE_WINDOW", self.root.destroy)
		self.root.title(self.BW_TITLE)
		self.root.configure(bg=self.BG_COLOR)
		self.canvas = tkinter.Canvas(
			self.root,
			bg=self.BG_COLOR,
			width=self.BW_WIDTH * self.BW_ZOOM,
			height=self.BW_HEIGHT * self.BW_ZOOM,
			bd=0,
			highlightthickness=0,
			relief="ridge"
		)
		self.canvas.pack()

_casioplot_window: _CasioPlotWindow = _CasioPlotWindow()
_casioplot_window.root.update()

def show_screen():
	pass

def clear_screen():
	_casioplot_window.clear_screen()
	_casioplot_window.root.update()

def set_pixel(x: int, y: int, color: tuple[int, int, int]=(0, 0, 0)):
	_casioplot_window.set_pixel(x, y, color)
	_casioplot_window.root.update()

def get_pixel(x: int, y: int) -> tuple[int, int, int]:
	return _casioplot_window.get_pixel(x, y)

CASIOPLOT_MEDIUM = [
	(3, [0]),
	(1, [1,1,1,0,1]),
	(3, [1,0,1,1,0,1]),
	(5, [0,1,0,1,0,1,1,1,1,1,0,1,0,1,0,1,1,1,1,1,0,1,0,1]),
	(5, [0,1,1,1,1,1,0,1,0,0,0,1,1,1,0,0,0,1,0,1,1,1,1,1]),
	(4, [0,0,0,0,1,0,0,1,0,0,1,0,0,1,0,0,1,0,0,1]),
	(4, [0,1,0,0,1,0,1,0,0,1,0,0,1,0,1,0,1,1,0,1]),
	(2, [1,1,0,1,1]),
	(2, [0,1,1,0,1,0,1,0,0,1]),
	(2, [1,0,0,1,0,1,0,1,1]),
	(5, [0,0,0,0,0,1,0,1,0,1,0,1,1,1,0,1,0,1,0,1]),
	(3, [0,0,0,0,1,0,1,1,1,0,1]),
	(2, [0,0,0,0,1,1,0,1,1]),
	(3, [0,0,0,0,0,0,1,1,1]),
	(3, [0,0,0,0,0,0,0,0,0,1,1,0,1,1]),
	(3, [0,0,0,0,0,1,0,1,0,1]),
	(3, [1,1,1,1,0,1,1,0,1,1,0,1,1,1,1]),
	(3, [0,1,0,0,1,0,0,1,0,0,1,0,0,1]),
	(3, [1,1,1,0,0,1,1,1,1,1,0,0,1,1,1]),
	(3, [1,1,1,0,0,1,1,1,1,0,0,1,1,1,1]),
	(3, [1,0,1,1,0,1,1,0,1,1,1,1,0,0,1]),
	(3, [1,1,1,1,0,0,1,1,1,0,0,1,1,1,1]),
	(3, [1,1,1,1,0,0,1,1,1,1,0,1,1,1,1]),
	(3, [1,1,1,1,0,1,0,0,1,0,0,1,0,0,1]),
	(3, [1,1,1,1,0,1,1,1,1,1,0,1,1,1,1]),
	(3, [1,1,1,1,0,1,1,1,1,0,0,1,1,1,1]),
	(2, [1,1,1,1,0,0,1,1,1,1]),
	(2, [1,1,1,1,0,0,0,1,1]),
	(3, [0,0,1,0,1,0,1,0,0,0,1,0,0,0,1]),
	(3, [0,0,0,1,1,1,0,0,0,1,1,1]),
	(3, [1,0,0,0,1,0,0,0,1,0,1,0,1]),
	(3, [1,1,0,0,0,1,0,1,0,0,0,0,0,1]),
	(5, [0,1,1,1,0,0,0,0,0,1,0,1,1,0,1,1,0,0,1,1,0,1,1,1]),
	(3, [0,1,0,1,0,1,1,1,1,1,0,1,1,0,1]),
	(3, [1,1,0,1,0,1,1,1,0,1,0,1,1,1]),
	(3, [0,1,1,1,0,0,1,0,0,1,0,0,0,1,1]),
	(3, [1,1,0,1,0,1,1,0,1,1,0,1,1,1]),
	(3, [1,1,1,1,0,0,1,1,1,1,0,0,1,1,1]),
	(3, [1,1,1,1,0,0,1,1,1,1,0,0,1]),
	(3, [0,1,1,1,0,0,1,0,1,1,0,1,0,1,1]),
	(3, [1,0,1,1,0,1,1,1,1,1,0,1,1,0,1]),
	(3, [1,1,1,0,1,0,0,1,0,0,1,0,1,1,1]),
	(3, [0,0,1,0,0,1,0,0,1,1,0,1,0,1]),
	(4, [1,0,0,1,1,0,1,0,1,1,0,0,1,0,1,0,1,0,0,1]),
	(3, [1,0,0,1,0,0,1,0,0,1,0,0,1,1,1]),
	(5, [1,0,0,0,1,1,1,0,1,1,1,0,1,0,1,1,0,0,0,1,1,0,0,0,1]),
	(5, [1,0,0,0,1,1,1,0,0,1,1,0,1,0,1,1,0,0,1,1,1,0,0,0,1]),
	(3, [0,1,0,1,0,1,1,0,1,1,0,1,0,1]),
	(3, [1,1,0,1,0,1,1,1,0,1,0,0,1]),
	(5, [0,1,1,1,0,1,0,0,0,1,1,0,1,0,1,1,0,0,1,0,0,1,1,0,1]),
	(3, [1,1,0,1,0,1,1,1,0,1,0,1,1,0,1]),
	(3, [0,1,1,1,0,0,0,1,0,0,0,1,1,1]),
	(3, [1,1,1,0,1,0,0,1,0,0,1,0,0,1]),
	(3, [1,0,1,1,0,1,1,0,1,1,0,1,1,1,1]),
	(3, [1,0,1,1,0,1,1,0,1,1,0,1,0,1]),
	(5, [1,0,0,0,1,1,0,0,0,1,1,0,1,0,1,1,0,1,0,1,0,1,0,1]),
	(3, [1,0,1,1,0,1,0,1,0,1,0,1,1,0,1]),
	(3, [1,0,1,1,0,1,0,1,0,0,1,0,0,1]),
	(3, [1,1,1,0,0,1,0,1,0,1,0,0,1,1,1]),
	(2, [1,1,1,0,1,0,1,0,1,1]),
	(3, [1,0,0,1,0,0,0,1,0,0,1,0,0,0,1,0,0,1]),
	(2, [1,1,0,1,0,1,0,1,1,1]),
	(3, [0,1,0,1,0,1]),
	(3, [0,0,0,0,0,0,0,0,0,0,0,0,1,1,1]),
	(2, [1,1,1,0,0,1]),
	(3, [0,1,0,0,0,1,0,1,1,1,0,1,0,1,1]),
	(3, [1,0,0,1,0,0,1,1,1,1,0,1,1,1]),
	(3, [0,0,0,0,1,1,1,0,0,1,0,0,0,1,1]),
	(3, [0,0,1,0,0,1,1,1,1,1,0,1,0,1,1]),
	(3, [0,1,0,1,0,1,1,1,1,1,0,0,0,1,1]),
	(3, [0,0,1,0,1,0,1,1,1,0,1,0,0,1]),
	(3, [0,1,1,1,0,1,0,1,1,0,0,1,1,1]),
	(3, [1,0,0,1,0,0,1,1,0,1,0,1,1,0,1]),
	(1, [0,1,0,1,1]),
	(3, [0,0,1,0,0,0,0,0,1,1,0,1,0,1]),
	(3, [1,0,0,1,0,0,1,0,1,1,1,0,1,0,1]),
	(3, [1,1,0,0,1,0,0,1,0,0,1,0,1,1,1]),
	(5, [0,0,0,0,0,1,1,0,1,0,1,0,1,0,1,1,0,1,0,1,1,0,1,0,1]),
	(4, [0,0,0,0,1,0,1,0,1,1,0,1,1,0,0,1,1,0,0,1]),
	(3, [0,0,0,0,1,0,1,0,1,1,0,1,0,1]),
	(3, [0,0,0,1,1,0,1,0,1,1,1,0,1]),
	(3, [0,0,0,0,1,1,1,0,1,0,1,1,0,0,1]),
	(4, [0,0,0,0,1,0,1,1,1,1,0,0,1,0,0,0,1]),
	(3, [0,1,1,1,0,0,0,1,0,0,0,1,1,1]),
	(3, [0,1,0,1,1,1,0,1,0,0,1,0,0,0,1]),
	(3, [0,0,0,1,0,1,1,0,1,1,0,1,1,1,1]),
	(3, [0,0,0,1,0,1,1,0,1,1,0,1,0,1]),
	(5, [0,0,0,0,0,1,0,0,0,1,1,0,1,0,1,1,0,1,0,1,0,1,0,1]),
	(3, [0,0,0,1,0,1,0,1,0,1,0,1,1,0,1]),
	(3, [0,0,0,1,0,1,1,0,1,0,1,0,1]),
	(3, [0,0,0,1,1,1,0,1,0,1,0,0,1,1,1]),
	(3, [0,1,1,0,1,0,1,0,0,0,1,0,0,1,1]),
	(1, [1,1,1,1,1]),
	(3, [1,1,0,0,1,0,0,0,1,0,1,0,1,1]),
	(4, [0,0,0,0,0,1,0,1,1,0,1])
]

CASIOPLOT_LARGE = [
	(6, [0]),
	(6, [0,0,0,1,0,0,0,0,0,1,0,0,0,0,0,1,0,0,0,0,0,1,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,1]),
	(6, [0,0,1,0,1,0,0,0,1,0,1,0,0,0,1,0,1]),
	(6, [0,0,1,0,1,0,0,0,1,0,1,0,0,1,1,1,1,1,0,0,1,0,1,0,0,1,1,1,1,1,0,0,1,0,1,0,0,0,1,0,1]),
	(6, [0,0,0,1,0,0,0,0,1,1,1,1,0,1,0,1,0,0,0,0,1,1,1,0,0,0,0,1,0,1,0,1,1,1,1,0,0,0,0,1]),
	(6, [0,1,1,0,0,0,0,1,1,0,0,1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1,0,0,1,1,0,0,0,0,1,1]),
	(6, [0,0,1,1,0,0,0,1,0,0,1,0,0,1,0,1,0,0,0,0,1,0,0,0,0,1,0,1,0,1,0,1,0,0,1,0,0,0,1,1,0,1]),
	(6, [0,0,1,1,0,0,0,0,0,1,0,0,0,0,1]),
	(6, [0,0,0,0,1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,0,1,0,0,0,0,0,1,0,0,0,0,0,0,1,0,0,0,0,0,0,1]),
	(6, [0,0,1,0,0,0,0,0,0,1,0,0,0,0,0,0,1,0,0,0,0,0,1,0,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1]),
	(6, [0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,1,0,1,0,0,1,1,1,0,0,0,1,1,1,0,0,1,0,1,0,1,0,0,0,1]),
	(6, [0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,1,0,0,0,1,1,1,1,1,0,0,0,1,0,0,0,0,0,1]),
	(6, [0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,0,0,0,1,0,0,0,0,1]),
	(6, [0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1]),
	(6, [0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,0,0,1,1]),
	(6, [0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1]),
	(6, [0,0,1,1,1,0,0,1,0,0,0,1,0,1,0,0,1,1,0,1,0,1,0,1,0,1,1,0,0,1,0,1,0,0,0,1,0,0,1,1,1]),
	(6, [0,0,0,1,0,0,0,0,1,1,0,0,0,0,0,1,0,0,0,0,0,1,0,0,0,0,0,1,0,0,0,0,0,1,0,0,0,0,1,1,1]),
	(6, [0,0,1,1,1,0,0,1,0,0,0,1,0,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1,1,1,1,1]),
	(6, [0,1,1,1,1,1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,0,0,1,0,0,0,0,0,0,1,0,1,0,0,0,1,0,0,1,1,1]),
	(6, [0,0,0,0,1,0,0,0,0,1,1,0,0,0,1,0,1,0,0,1,0,0,1,0,0,1,1,1,1,1,0,0,0,0,1,0,0,0,0,0,1]),
	(6, [0,1,1,1,1,1,0,1,0,0,0,0,0,1,1,1,1,0,0,0,0,0,0,1,0,0,0,0,0,1,0,1,0,0,0,1,0,0,1,1,1]),
	(6, [0,0,0,1,1,0,0,0,1,0,0,0,0,1,0,0,0,0,0,1,1,1,1,0,0,1,0,0,0,1,0,1,0,0,0,1,0,0,1,1,1]),
	(6, [0,1,1,1,1,1,0,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,0,1,0,0,0,0,0,1,0,0,0,0,0,1]),
	(6, [0,0,1,1,1,0,0,1,0,0,0,1,0,1,0,0,0,1,0,0,1,1,1,0,0,1,0,0,0,1,0,1,0,0,0,1,0,0,1,1,1]),
	(6, [0,0,1,1,1,0,0,1,0,0,0,1,0,1,0,0,0,1,0,0,1,1,1,1,0,0,0,0,0,1,0,0,0,0,1,0,0,0,1,1]),
	(6, [0,0,0,0,0,0,0,0,1,1,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,1,1,0,0,0,0,1,1]),
	(6, [0,0,0,0,0,0,0,0,1,1,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,1,1,0,0,0,0,0,1,0,0,0,0,1]),
	(6, [0,0,0,0,1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,0,0,1,0,0,0,0,0,0,1,0,0,0,0,0,0,1]),
	(6, [0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,0,0,0,0,0,0,0,1,1,1,1,1]),
	(6, [0,0,1,0,0,0,0,0,0,1,0,0,0,0,0,0,1,0,0,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1]),
	(6, [0,0,1,1,1,0,0,1,0,0,0,1,0,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,1]),
	(6, [0,0,1,1,1,0,0,1,0,0,0,1,0,0,0,0,0,1,0,0,1,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,0,1,1,1]),
	(6, [0,0,1,1,1,0,0,1,0,0,0,1,0,1,0,0,0,1,0,1,1,1,1,1,0,1,0,0,0,1,0,1,0,0,0,1,0,1,0,0,0,1]),
	(6, [0,1,1,1,1,0,0,1,0,0,0,1,0,1,0,0,0,1,0,1,1,1,1,0,0,1,0,0,0,1,0,1,0,0,0,1,0,1,1,1,1]),
	(6, [0,0,1,1,1,0,0,1,0,0,0,1,0,1,0,0,0,0,0,1,0,0,0,0,0,1,0,0,0,0,0,1,0,0,0,1,0,0,1,1,1]),
	(6, [0,1,1,1,0,0,0,1,0,0,1,0,0,1,0,0,0,1,0,1,0,0,0,1,0,1,0,0,0,1,0,1,0,0,1,0,0,1,1,1]),
	(6, [0,1,1,1,1,1,0,1,0,0,0,0,0,1,0,0,0,0,0,1,1,1,1,0,0,1,0,0,0,0,0,1,0,0,0,0,0,1,1,1,1,1]),
	(6, [0,1,1,1,1,1,0,1,0,0,0,0,0,1,0,0,0,0,0,1,1,1,1,0,0,1,0,0,0,0,0,1,0,0,0,0,0,1]),
	(6, [0,0,1,1,1,0,0,1,0,0,0,1,0,1,0,0,0,0,0,1,0,1,1,1,0,1,0,0,0,1,0,1,0,0,0,1,0,0,1,1,1,1]),
	(6, [0,1,0,0,0,1,0,1,0,0,0,1,0,1,0,0,0,1,0,1,1,1,1,1,0,1,0,0,0,1,0,1,0,0,0,1,0,1,0,0,0,1]),
	(6, [0,0,1,1,1,0,0,0,0,1,0,0,0,0,0,1,0,0,0,0,0,1,0,0,0,0,0,1,0,0,0,0,0,1,0,0,0,0,1,1,1]),
	(6, [0,0,0,1,1,1,0,0,0,0,1,0,0,0,0,0,1,0,0,0,0,0,1,0,0,0,0,0,1,0,0,1,0,0,1,0,0,0,1,1]),
	(6, [0,1,0,0,0,1,0,1,0,0,1,0,0,1,0,1,0,0,0,1,1,0,0,0,0,1,0,1,0,0,0,1,0,0,1,0,0,1,0,0,0,1]),
	(6, [0,1,0,0,0,0,0,1,0,0,0,0,0,1,0,0,0,0,0,1,0,0,0,0,0,1,0,0,0,0,0,1,0,0,0,0,0,1,1,1,1,1]),
	(6, [0,1,0,0,0,1,0,1,1,0,1,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,0,0,1,0,1,0,0,0,1,0,1,0,0,0,1]),
	(6, [0,1,0,0,0,1,0,1,0,0,0,1,0,1,1,0,0,1,0,1,0,1,0,1,0,1,0,0,1,1,0,1,0,0,0,1,0,1,0,0,0,1]),
	(6, [0,0,1,1,1,0,0,1,0,0,0,1,0,1,0,0,0,1,0,1,0,0,0,1,0,1,0,0,0,1,0,1,0,0,0,1,0,0,1,1,1]),
	(6, [0,1,1,1,1,0,0,1,0,0,0,1,0,1,0,0,0,1,0,1,1,1,1,0,0,1,0,0,0,0,0,1,0,0,0,0,0,1]),
	(6, [0,0,1,1,1,0,0,1,0,0,0,1,0,1,0,0,0,1,0,1,0,0,0,1,0,1,0,1,0,1,0,1,0,0,1,0,0,0,1,1,0,1]),
	(6, [0,1,1,1,1,0,0,1,0,0,0,1,0,1,0,0,0,1,0,1,1,1,1,0,0,1,0,1,0,0,0,1,0,0,1,0,0,1,0,0,0,1]),
	(6, [0,0,1,1,1,0,0,1,0,0,0,1,0,1,0,0,0,0,0,0,1,1,1,0,0,0,0,0,0,1,0,1,0,0,0,1,0,0,1,1,1]),
	(6, [0,1,1,1,1,1,0,0,0,1,0,0,0,0,0,1,0,0,0,0,0,1,0,0,0,0,0,1,0,0,0,0,0,1,0,0,0,0,0,1]),
	(6, [0,1,0,0,0,1,0,1,0,0,0,1,0,1,0,0,0,1,0,1,0,0,0,1,0,1,0,0,0,1,0,1,0,0,0,1,0,0,1,1,1]),
	(6, [0,1,0,0,0,1,0,1,0,0,0,1,0,1,0,0,0,1,0,1,0,0,0,1,0,1,0,0,0,1,0,0,1,0,1,0,0,0,0,1]),
	(6, [0,1,0,0,0,1,0,1,0,0,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,0,1,0,1]),
	(6, [0,1,0,0,0,1,0,1,0,0,0,1,0,0,1,0,1,0,0,0,0,1,0,0,0,0,1,0,1,0,0,1,0,0,0,1,0,1,0,0,0,1]),
	(6, [0,1,0,0,0,1,0,1,0,0,0,1,0,1,0,0,0,1,0,0,1,0,1,0,0,0,0,1,0,0,0,0,0,1,0,0,0,0,0,1]),
	(6, [0,1,1,1,1,1,0,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,0,1,1,1,1,1]),
	(6, [0,0,1,1,1,0,0,0,1,0,0,0,0,0,1,0,0,0,0,0,1,0,0,0,0,0,1,0,0,0,0,0,1,0,0,0,0,0,1,1,1]),
	(6, [0,0,0,0,0,0,0,1,0,0,0,0,0,0,1,0,0,0,0,0,0,1,0,0,0,0,0,0,1,0,0,0,0,0,0,1]),
	(6, [0,0,1,1,1,0,0,0,0,0,1,0,0,0,0,0,1,0,0,0,0,0,1,0,0,0,0,0,1,0,0,0,0,0,1,0,0,0,1,1,1]),
	(6, [0,0,0,1,0,0,0,0,1,0,1,0,0,1,0,0,0,1]),
	(6, [0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1]),
	(6, [0,0,1,1,0,0,0,0,0,1,0,0,0,0,0,0,1]),
	(6, [0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,0,0,0,0,0,0,1,0,0,1,1,1,1,0,1,0,0,0,1,0,0,1,1,1,1]),
	(6, [0,1,0,0,0,0,0,1,0,0,0,0,0,1,0,1,1,0,0,1,1,0,0,1,0,1,0,0,0,1,0,1,0,0,0,1,0,1,1,1,1]),
	(6, [0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,0,0,1,0,0,0,0,0,1,0,0,0,0,0,1,0,0,0,1,0,0,1,1,1]),
	(6, [0,0,0,0,0,1,0,0,0,0,0,1,0,0,1,1,0,1,0,1,0,0,1,1,0,1,0,0,0,1,0,1,0,0,0,1,0,0,1,1,1,1]),
	(6, [0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,0,0,1,0,0,0,1,0,1,1,1,1,1,0,1,0,0,0,0,0,0,1,1,1]),
	(6, [0,0,0,0,1,1,0,0,0,1,0,0,0,0,1,1,1,0,0,0,0,1,0,0,0,0,0,1,0,0,0,0,0,1,0,0,0,0,0,1]),
	(6, [0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,0,1,0,0,0,1,0,0,1,1,1,1,0,0,0,0,0,1,0,0,1,1,1]),
	(6, [0,1,0,0,0,0,0,1,0,0,0,0,0,1,0,1,1,0,0,1,1,0,0,1,0,1,0,0,0,1,0,1,0,0,0,1,0,1,0,0,0,1]),
	(6, [0,0,0,1,0,0,0,0,0,0,0,0,0,0,1,1,0,0,0,0,0,1,0,0,0,0,0,1,0,0,0,0,0,1,0,0,0,0,1,1,1]),
	(6, [0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,1,1,0,0,0,0,0,1,0,0,0,0,0,1,0,0,1,0,0,1,0,0,0,1,1]),
	(6, [0,0,1,0,0,0,0,0,1,0,0,0,0,0,1,0,0,1,0,0,1,0,1,0,0,0,1,1,0,0,0,0,1,0,1,0,0,0,1,0,0,1]),
	(6, [0,0,1,1,0,0,0,0,0,1,0,0,0,0,0,1,0,0,0,0,0,1,0,0,0,0,0,1,0,0,0,0,0,1,0,0,0,0,1,1,1]),
	(6, [0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,1,0,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1]),
	(6, [0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,1,0,0,1,1,0,0,1,0,1,0,0,0,1,0,1,0,0,0,1,0,1,0,0,0,1]),
	(6, [0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,0,0,1,0,0,0,1,0,1,0,0,0,1,0,1,0,0,0,1,0,0,1,1,1]),
	(6, [0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,0,0,1,0,0,0,1,0,1,1,1,1,0,0,1,0,0,0,0,0,1]),
	(6, [0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,0,1,0,0,0,1,0,0,1,1,1,1,0,0,0,0,0,1,0,0,0,0,0,1]),
	(6, [0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,1,0,0,1,1,0,0,1,0,1,0,0,0,0,0,1,0,0,0,0,0,1]),
	(6, [0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,0,1,0,0,0,0,0,0,1,1,1,0,0,0,0,0,0,1,0,1,1,1,1]),
	(6, [0,0,1,0,0,0,0,1,1,1,0,0,0,0,1,0,0,0,0,0,1,0,0,0,0,0,1,0,0,0,0,0,1,0,0,1,0,0,0,1,1]),
	(6, [0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,1,0,0,0,1,0,1,0,0,0,1,0,1,0,0,1,1,0,0,1,1,0,1]),
	(6, [0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,1,0,0,0,1,0,0,1,0,1,0,0,0,1,0,1,0,0,0,0,1]),
	(6, [0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,1,0,0,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,0,1,0,1]),
	(6, [0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,1,0,0,0,1,1,0,0,0,0,1,0,0,0,0,1,1,0,0,0,1,0,0,1,1]),
	(6, [0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,1,0,0,1,0,0,0,1,1,0,0,0,0,1,0,0,0,1,1]),
	(6, [0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1,1,1,1,1]),
	(6, [0,0,0,1,0,0,0,0,1,0,0,0,0,0,1,0,0,0,0,1,0,0,0,0,0,0,1,0,0,0,0,0,1,0,0,0,0,0,0,1]),
	(6, [0,0,0,1,0,0,0,0,0,1,0,0,0,0,0,1,0,0,0,0,0,1,0,0,0,0,0,1,0,0,0,0,0,1,0,0,0,0,0,1]),
	(6, [0,0,0,1,0,0,0,0,0,0,1,0,0,0,0,0,1,0,0,0,0,0,0,1,0,0,0,0,1,0,0,0,0,0,1,0,0,0,0,1]),
	(6, [0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,1,0,1,0,1,0,1,0,1,0,0,1])
]

def draw_string(x: int, y: int, s: str, color: tuple[int, int, int]=(0, 0, 0),
				size: str="medium"):
	charset = CASIOPLOT_LARGE if size == "large" else CASIOPLOT_MEDIUM
	for c in s:
		i = ord(c) - 32
		if i < 0 or i > 95:
			i = 0
		char_width, pixels = charset[i]
		xi = 0
		yi = y
		for pixel in pixels:
			if pixel == 1:
				set_pixel(x + xi, yi, color)
			xi += 1
			if xi >= char_width:
				xi = 0
				yi += 1
		x += char_width + 1
